# GroupIdRecords

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDate**](LastModifiedDate.md) |  | [optional] 
**total** | **int** |  | 
**page** | **int** |  | 
**page_size** | **int** |  | 
**group_id_record** | [**list[GroupIdRecord]**](GroupIdRecord.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


